==> haskell-mwc-random-0.13.4.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.13.4.0
id: mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
key: mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.Distributions
    System.Random.MWC.CondensedTable
abi: b69b6f6ee695c1fc568f530110cfd9c0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.4.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/mwc-random-0.13.4.0
hs-libraries: HSmwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
depends:
    base-4.9.0.0 primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa time-1.6.0.1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.13.5.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mwc-random
version: 0.13.5.0
id: mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
key: mwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/mwc-random
synopsis: Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    System.Random.MWC System.Random.MWC.Distributions
    System.Random.MWC.CondensedTable
abi: a178be10448c3a26b75b704381cf1784
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/mwc-random-0.13.5.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/mwc-random-0.13.5.0
hs-libraries: HSmwc-random-0.13.5.0-LMmPnBqFcyXKNTZwO31mEb
depends:
    base-4.9.0.0 primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa time-1.6.0.1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html: /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
